pub struct ColorContrast;Expand description
Provides utilities for calculating and ensuring color contrast ratios.
Used to determine if text colors meet WCAG accessibility standards when displayed on specific background colors.
Implementations
Sourceimpl ColorContrast
impl ColorContrast
Sourcepub fn has_sufficient_contrast(
text_color: &ColorType,
bg_color: &ColorType,
) -> bool
pub fn has_sufficient_contrast( text_color: &ColorType, bg_color: &ColorType, ) -> bool
Sourcepub fn ensure_sufficient_contrast(
text_color: &ColorType,
bg_color: &ColorType,
) -> ColorType
pub fn ensure_sufficient_contrast( text_color: &ColorType, bg_color: &ColorType, ) -> ColorType
Sourcepub fn darken_color_for_contrast(
text_rgb: (u8, u8, u8),
bg_rgb: (u8, u8, u8),
) -> ColorType
pub fn darken_color_for_contrast( text_rgb: (u8, u8, u8), bg_rgb: (u8, u8, u8), ) -> ColorType